# Copyright 2022 The JAX Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Module for state."""
from jax._src.state.types import (ShapedArrayRef, ReadEffect, WriteEffect,
                                  AccumEffect, StateEffect, RefEffect,
                                  get_ref_state_effects)
from jax._src.state.primitives import (ref_get, ref_set, ref_swap,
                                       ref_addupdate, get_p, swap_p,
                                       addupdate_p)
from jax._src.state.discharge import discharge_state, register_discharge_rule
